==> keyclic_sdk_api-1.28.11.tar.gz: lib/model/business_activity_metadata_schema_properties.dart <==
part of keyclic_sdk_api.api;

class BusinessActivityMetadataSchemaProperties {
  List<String> enum_ = [];

  int maxItems = null;

  int minItems = null;

  String pattern = null;

  BusinessActivityMetadataSchemaProperties();

  @override
  String toString() {
    return 'BusinessActivityMetadataSchemaProperties[enum_=$enum_, maxItems=$maxItems, minItems=$minItems, pattern=$pattern, ]';
  }

  BusinessActivityMetadataSchemaProperties.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    enum_ = (json['enum'] as List)?.map((item) => item as String)?.toList();
    maxItems = json['maxItems'];
    minItems = json['minItems'];
    pattern = json['pattern'];
  }

  Map<String, dynamic> toJson() {
    return {
      'enum_': enum_,
      'maxItems': maxItems,
      'minItems': minItems,
      'pattern': pattern
    };
  }

  static List<BusinessActivityMetadataSchemaProperties> listFromJson(
      List<dynamic> json) {
    return json == null
        ? new List<BusinessActivityMetadataSchemaProperties>()
        : json
            .map((value) =>
                new BusinessActivityMetadataSchemaProperties.fromJson(value))
            .toList();
  }

  static Map<String, BusinessActivityMetadataSchemaProperties> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, BusinessActivityMetadataSchemaProperties>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) => map[key] =
          new BusinessActivityMetadataSchemaProperties.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.28.13.tar.gz: lib/model/business_activity_metadata_schema_properties.dart <==
part of keyclic_sdk_api.api;

class BusinessActivityMetadataSchemaProperties {
  String type = null;

  List<String> enum_ = [];

  int maxItems = null;

  int minItems = null;

  String pattern = null;

  bool required = null;

  BusinessActivityMetadataSchemaProperties();

  @override
  String toString() {
    return 'BusinessActivityMetadataSchemaProperties[type=$type, enum_=$enum_, maxItems=$maxItems, minItems=$minItems, pattern=$pattern, required=$required, ]';
  }

  BusinessActivityMetadataSchemaProperties.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    type = json['type'];
    enum_ = (json['enum'] as List)?.map((item) => item as String)?.toList();
    maxItems = json['maxItems'];
    minItems = json['minItems'];
    pattern = json['pattern'];
    required = json['required'];
  }

  Map<String, dynamic> toJson() {
    return {
      'type': type,
      'enum_': enum_,
      'maxItems': maxItems,
      'minItems': minItems,
      'pattern': pattern,
      'required': required
    };
  }

  static List<BusinessActivityMetadataSchemaProperties> listFromJson(
      List<dynamic> json) {
    return json == null
        ? new List<BusinessActivityMetadataSchemaProperties>()
        : json
            .map((value) =>
                new BusinessActivityMetadataSchemaProperties.fromJson(value))
            .toList();
  }

  static Map<String, BusinessActivityMetadataSchemaProperties> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, BusinessActivityMetadataSchemaProperties>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) => map[key] =
          new BusinessActivityMetadataSchemaProperties.fromJson(value));
    }
    return map;
  }
}
